@@ -10,4 +10,8 @@ RESEARCH_ORG_DOMAINS = {
     'mpimf-heidelberg.mpg.de': [u'Max Planck Institute for Medical Research'],
     'mpg.de': [u'Max Planck Institute'],
     'dkfz-heidelberg.de': [u'German Cancer Research Center'],
+    'dkfz.de': [u'German Cancer Research Center'],
+    'helmholtz-hzi.de': [u'Helmholtz Centre for Infection Research'],
+    'univ-tlse3.fr': [u'Université Paul Sabatier'],
+    'santafe-conicet.gov.ar': [u'Instituto de Agrobiotecnología del Litoral'],
 }
